<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:date="http://exslt.org/dates-and-times" xmlns:exsl="http://exslt.org/common"
	extension-element-prefixes="date exsl" xmlns:csv="csv:csv">

	<xsl:output method="text" encoding="ISO-8859-1" />
	<xsl:strip-space elements="*" />
	<xsl:variable name="delimiter" select="';'" />

	<xsl:decimal-format name="money" decimal-separator="," grouping-separator="." NaN="0,00" />
	<xsl:decimal-format name="amount" decimal-separator="," grouping-separator="." NaN="0" />
	<xsl:decimal-format name="percent" decimal-separator="," grouping-separator="." NaN="0" />

	<xsl:template name="formatdate">
		<xsl:param name="datestr" />

		<xsl:variable name="yyyy">
			<xsl:value-of select="substring($datestr,1,4)" />
		</xsl:variable>

		<xsl:variable name="mm">
			<xsl:value-of select="substring($datestr,6,2)" />
		</xsl:variable>

		<xsl:variable name="dd">
			<xsl:value-of select="substring($datestr,9,2)" />
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$datestr != ''">
				<xsl:value-of select="$dd" />
				<xsl:value-of select="'.'" />
				<xsl:value-of select="$mm" />
				<xsl:value-of select="'.'" />
				<xsl:value-of select="$yyyy" />
			</xsl:when>
			<xsl:otherwise>
				&#160;
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="formattime">
		<xsl:param name="timestr" />

		<xsl:variable name="time">
			<xsl:value-of select="substring($timestr,12,8)" />
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$timestr != ''">
				<xsl:value-of select="$time" />
			</xsl:when>
			<xsl:otherwise>
				&#160;
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="formatdatetime">
		<xsl:param name="datetimestr" />

		<xsl:variable name="yyyy">
			<xsl:value-of select="substring($datetimestr,1,4)" />
		</xsl:variable>

		<xsl:variable name="mm">
			<xsl:value-of select="substring($datetimestr,6,2)" />
		</xsl:variable>

		<xsl:variable name="dd">
			<xsl:value-of select="substring($datetimestr,9,2)" />
		</xsl:variable>

		<xsl:variable name="time">
			<xsl:value-of select="substring($datetimestr,12,8)" />
		</xsl:variable>


		<xsl:choose>
			<xsl:when test="$datetimestr != ''">
				<xsl:value-of select="$dd" />
				<xsl:value-of select="'.'" />
				<xsl:value-of select="$mm" />
				<xsl:value-of select="'.'" />
				<xsl:value-of select="$yyyy" />
				<xsl:text>, </xsl:text>
				<xsl:value-of select="$time" />
			</xsl:when>
			<xsl:otherwise>&#160;</xsl:otherwise>
		</xsl:choose>

	</xsl:template>



	<xsl:template match="/">


		<!-- HEADER -->
		<xsl:text>&#xa;</xsl:text>
		<xsl:value-of select='"Ansicht nach Wertstellungsdatum"' />
		
		<xsl:text>&#xa;</xsl:text>

		<xsl:text>Von</xsl:text><xsl:value-of select="$delimiter" />

		<xsl:call-template name="formatdate">
			<xsl:with-param name="datestr" select="report/report-params/DATE" />
		</xsl:call-template>
		<xsl:value-of select="$delimiter" />

		<xsl:text>Bis</xsl:text><xsl:value-of select="$delimiter" />
		<xsl:call-template name="formatdate">
			<xsl:with-param name="datestr" select="report/report-params/TODATE" />
		</xsl:call-template>
		<xsl:value-of select="$delimiter" />

		<!-- AUSGEGEBEN -->

		<xsl:variable name="sales_voucher_out" select="exsl:node-set(report/sales_voucher_out)" />
		<xsl:if test="count($sales_voucher_out/row) != 0">

			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>Ausgegeben</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>

			<xsl:text>Ausgabedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Einlösedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kassierer</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Gutschein Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Betrag</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>enthaltener Rabatt</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Beleg Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kunde</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Telefon</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Handy</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>EMail</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>PLZ</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Ort</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Straße</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:text>&#xa;</xsl:text>

			<xsl:for-each select="report/sales_voucher_out/row">

				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_use_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />
				<xsl:choose>
					<xsl:when test="redeemed_sales_voucher_state = '6'">
						<xsl:text>Deaktiviert</xsl:text>
					</xsl:when>
					<xsl:otherwise>	
						<xsl:if test="redeemed_sales_voucher_use_ts">
							<xsl:call-template name="formatdate"><xsl:with-param name="datestr" select="redeemed_sales_voucher_use_ts" /></xsl:call-template>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="employee_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="voucher_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="format-number(voucher_value, '###.##0,00', 'money')" />
				<xsl:value-of select="$delimiter" />
				<xsl:if test="sales_voucher_value_rebate > 0">	
					<xsl:value-of select="format-number(sales_voucher_value_rebate, '###.##0,00', 'money')" />
				</xsl:if>
				<xsl:value-of select="$delimiter" />
				<xsl:value-of select="sales_inv_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="customer_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="phone" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="mobile" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="email" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="postal_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="city" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="street" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>&#xa;</xsl:text>
			</xsl:for-each>

			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>Summe</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:value-of select="format-number(sum(report/sales_voucher_out/row/voucher_value ), '###.##0,00', 'money')" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>&#xa;</xsl:text>

		</xsl:if>





		<!-- EINGELÖST -->
		<xsl:variable name="sales_voucher_in" select="exsl:node-set(report/sales_voucher_in)" />
		<xsl:if test="count($sales_voucher_in/row) != 0">

			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>Eingelöst</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>

			<xsl:text>Ausgabedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Einlösedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kassierer</xsl:text>
<xsl:value-of select="$delimiter" />
			<xsl:text>Gutschein Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Betrag</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>angerechneter Rabatt</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Beleg Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kunde</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Telefon</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Handy</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>EMail</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>PLZ</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Ort</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Straße</xsl:text>
			<xsl:value-of select="$delimiter" />


			<xsl:text>&#xa;</xsl:text>

			<xsl:for-each select="report/sales_voucher_in/row">

				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />
				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_use_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />

								<xsl:value-of select="employee_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="voucher_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="format-number(voucher_value, '###.##0,00', 'money')" />
				<xsl:value-of select="$delimiter" />
				<xsl:if test="sales_voucher_value_rebate_eff > 0">	
					<xsl:value-of select="format-number(sales_voucher_value_rebate_eff, '###.##0,00', 'money')" />
				</xsl:if>
				<xsl:value-of select="$delimiter" />
				<xsl:value-of select="sales_inv_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="customer_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="phone" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="mobile" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="email" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="postal_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="city" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="street" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>&#xa;</xsl:text>
			</xsl:for-each>

			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>Summe</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:value-of select="format-number(sum(report/sales_voucher_in/row/voucher_value), '###.##0,00', 'money')" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>&#xa;</xsl:text>

		</xsl:if>


		


		<!-- EINGELÖST VORM ZEITRAUM-->
		<xsl:variable name="sales_voucher_in2" select="exsl:node-set(report/sales_voucher_in2)" />
		<xsl:if test="count($sales_voucher_in2/row) != 0">
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>Eingelöste Gutscheine, die vor dem gewählten Zeitraum ausgegeben wurden</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>

			<xsl:text>Ausgabedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Einlösedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kassierer</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Gutschein Nr </xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Betrag</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>angerechneter Rabatt</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Beleg Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kunde</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Telefon</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Handy</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>EMail</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>PLZ</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Ort</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Straße</xsl:text>
			<xsl:value-of select="$delimiter" />


			<xsl:text>&#xa;</xsl:text>

			<xsl:for-each select="report/sales_voucher_in2/row">

				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />
				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_use_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />

								<xsl:value-of select="employee_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="voucher_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="format-number(voucher_value, '###.##0,00', 'money')" />
				<xsl:value-of select="$delimiter" />
				<xsl:value-of select="$delimiter" />
				<xsl:if test="sales_voucher_value_rebate_eff > 0">	
					<xsl:value-of select="format-number(sales_voucher_value_rebate_eff, '###.##0,00', 'money')" />
				</xsl:if>
				<xsl:value-of select="$delimiter" />
				<xsl:value-of select="sales_inv_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="customer_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="phone" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="mobile" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="email" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="postal_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="city" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="street" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>&#xa;</xsl:text>
			</xsl:for-each>

			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>Summe</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:value-of select="format-number(sum(report/sales_voucher_in2/row/voucher_value), '###.##0,00', 'money')" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>&#xa;</xsl:text>
		</xsl:if>

		


		<!-- EINGELÖST IN ANDEREN SALONS-->

		<xsl:variable name="voucher_uses_in_other_pos" select="exsl:node-set(report/voucher_uses_in_other_pos)" />
		<xsl:if test="count($voucher_uses_in_other_pos/row) != 0">
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>Eingelöst in anderen Salons</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>

			<xsl:text>Ausgabedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Einlösedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kassierer</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Gutschein Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Betrag</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>enthaltener Rabatt</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Beleg Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Salon</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kunde</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Telefon</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Handy</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>EMail</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>PLZ</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Ort</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Straße</xsl:text>
			<xsl:value-of select="$delimiter" />


			<xsl:text>&#xa;</xsl:text>

			<xsl:for-each select="report/voucher_uses_in_other_pos/row">

				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />
				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_use_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />

								<xsl:value-of select="employee_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="voucher_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="format-number(voucher_value, '###.##0,00', 'money')" />
				<xsl:value-of select="$delimiter" />
				<xsl:if test="ext_voucher_value_rebate_eff > 0">	
					<xsl:value-of select="format-number(ext_voucher_value_rebate_eff, '###.##0,00', 'money')" />
				</xsl:if>
				<xsl:value-of select="$delimiter" />
				<xsl:value-of select="sales_inv_cd" />
				<xsl:value-of select="$delimiter" />
				
				<xsl:value-of select="businessunit_nm" />
				<xsl:value-of select="$delimiter" />
				
				<xsl:value-of select="customer_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="phone" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="mobile" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="email" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="postal_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="city" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="street" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>&#xa;</xsl:text>
			</xsl:for-each>

			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>Summe</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:value-of select="format-number(sum(report/voucher_uses_in_other_pos/row/voucher_value), '###.##0,00', 'money')" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>&#xa;</xsl:text>
		</xsl:if>

		


		<!-- EINGELÖST Nicht zugeordnet oder aus anderen Salons-->

		<xsl:variable name="vouchers_in2" select="exsl:node-set(report/vouchers_in2)" />
		<xsl:if test="count($vouchers_in2/row) != 0">
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>Eingelöst (Nicht zugeordnet oder aus anderen Salons)</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>

			<xsl:text>Ausgabedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Einlösedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kassierer</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Gutschein Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Herkunft</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Betrag</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>angrechneter Rabatt</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Beleg Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kunde</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Telefon</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Handy</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>EMail</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>PLZ</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Ort</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Straße</xsl:text>
			<xsl:value-of select="$delimiter" />


			<xsl:text>&#xa;</xsl:text>

			<xsl:for-each select="report/vouchers_in2/row">

				<xsl:value-of select="$delimiter" />
				<xsl:value-of select="payment_ts_d" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="cashier_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="voucher_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="voucher_origin" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="format-number(payment, '###.##0,00', 'money')" />
				<xsl:value-of select="$delimiter" />
				<xsl:if test="ext_voucher_value_rebate_eff > 0">	
					<xsl:value-of select="format-number(ext_voucher_value_rebate_eff, '###.##0,00', 'money')" />
				</xsl:if>
				<xsl:value-of select="$delimiter" />
				<xsl:value-of select="sales_inv_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="customer_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="phone" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="mobile" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="email" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="postal_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="city" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="street" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>&#xa;</xsl:text>
			</xsl:for-each>

			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>Summe</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:value-of select="format-number(sum(report/vouchers_in2/row/payment), '###.##0,00', 'money')" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>&#xa;</xsl:text>
		</xsl:if>

		


		<!-- Ausgegeben stonierte Gutscheine-->

		<xsl:variable name="sales_voucher_out_storno" select="exsl:node-set(report/sales_voucher_out_storno)" />
		<xsl:if test="count($sales_voucher_out_storno/row) != 0">
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>Ausgegebene stornierte Gutscheine</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>

			<xsl:text>Ausgabedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Stornodatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kassierer</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Gutschein Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Betrag</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>enthaltener Rabatt</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Beleg Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kunde</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Telefon</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Handy</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>EMail</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>PLZ</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Ort</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Straße</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:text>&#xa;</xsl:text>

			<xsl:for-each select="report/sales_voucher_out_storno/row">

				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />
				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_use_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />

								<xsl:value-of select="employee_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="voucher_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="format-number(voucher_value, '###.##0,00', 'money')" />
				<xsl:value-of select="$delimiter" />
				<xsl:if test="sales_voucher_value_rebate > 0">	
					<xsl:value-of select="format-number(sales_voucher_value_rebate, '###.##0,00', 'money')" />
				</xsl:if>
				<xsl:value-of select="$delimiter" />
				<xsl:value-of select="sales_inv_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="customer_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="phone" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="mobile" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="email" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="postal_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="city" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="street" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>&#xa;</xsl:text>
			</xsl:for-each>

			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>Summe</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:value-of select="format-number(sum(report/sales_voucher_out_storno/row/voucher_value), '###.##0,00', 'money')" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>&#xa;</xsl:text>
		</xsl:if>

		


		<!-- Eingelöste stonierte Gutscheine-->

		<xsl:variable name="sales_voucher_in_storno" select="exsl:node-set(report/sales_voucher_in_storno)" />
		<xsl:if test="count($sales_voucher_in_storno/row) != 0">
			
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>Eingelöste stornierte Gutscheine</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>

			<xsl:text>Ausgabedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Stornodatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kassierer</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Gutschein Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Betrag</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>angerechnete Rabatte</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Beleg Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kunde</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Telefon</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Handy</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>EMail</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>PLZ</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Ort</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Straße</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:text>&#xa;</xsl:text>

			<xsl:for-each select="report/sales_voucher_in_storno/row">

				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />
				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_use_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />

								<xsl:value-of select="employee_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="voucher_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="format-number(voucher_value, '###.##0,00', 'money')" />
				<xsl:value-of select="$delimiter" />
				<xsl:if test="sales_voucher_value_rebate_eff > 0">	
					<xsl:value-of select="format-number(sales_voucher_value_rebate_eff, '###.##0,00', 'money')" />
				</xsl:if>
				<xsl:value-of select="$delimiter" />
				<xsl:value-of select="sales_inv_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="customer_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="phone" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="mobile" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="email" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="postal_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="city" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="street" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>&#xa;</xsl:text>
			</xsl:for-each>

			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>Summe</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:value-of select="format-number(sum(report/sales_voucher_in_storno/row/voucher_value), '###.##0,00', 'money')" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>&#xa;</xsl:text>
		</xsl:if>

			<!-- Deaktivierte Gutscheine-->

		<xsl:variable name="sales_voucher_out_disabled" select="exsl:node-set(report/sales_voucher_out_disabled)" />
		<xsl:if test="count($sales_voucher_out_disabled/row) != 0">
			
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>Deaktivierte Gutscheine</xsl:text>
			<xsl:text>&#xa;</xsl:text>
			<xsl:text>&#xa;</xsl:text>

			<xsl:text>Ausgabedatum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Deakt.-Datum</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kassierer</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Gutschein Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Betrag</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>enthaltene Rabatte</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Beleg Nr</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Kunde</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Telefon</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Handy</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>EMail</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>PLZ</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Ort</xsl:text>
			<xsl:value-of select="$delimiter" />
			<xsl:text>Straße</xsl:text>
			<xsl:value-of select="$delimiter" />


			<xsl:text>&#xa;</xsl:text>

			<xsl:for-each select="report/sales_voucher_out_disabled/row">

				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />
				<xsl:call-template name="formatdate">
					<xsl:with-param name="datestr" select="voucher_use_ts" />
				</xsl:call-template>
				<xsl:value-of select="$delimiter" />

								<xsl:value-of select="employee_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="voucher_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="format-number(voucher_value, '###.##0,00', 'money')" />
				<xsl:value-of select="$delimiter" />
				<xsl:if test="sales_voucher_value_rebate > 0">	
					<xsl:value-of select="format-number(sales_voucher_value_rebate, '###.##0,00', 'money')" />
				</xsl:if>
				<xsl:value-of select="$delimiter" />
				<xsl:value-of select="sales_inv_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="customer_nm" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="phone" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="mobile" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="email" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>#</xsl:text><xsl:value-of select="postal_cd" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="city" />
				<xsl:value-of select="$delimiter" />

				<xsl:value-of select="street" />
				<xsl:value-of select="$delimiter" />

				<xsl:text>&#xa;</xsl:text>
			</xsl:for-each>

			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>Summe</xsl:text>
			<xsl:value-of select="$delimiter" />

			<xsl:value-of select="format-number(sum(report/sales_voucher_out_disabled/row/voucher_value), '###.##0,00', 'money')" />
			<xsl:value-of select="$delimiter" />
			<xsl:text>&#xa;</xsl:text>

		</xsl:if>



	</xsl:template>

</xsl:stylesheet>